@@ -9,14 +9,14 @@
  *
  * Author: Krzysztof Luks <m00se@iq.pl>
  *
- * $Date: 2002/07/05 17:51:15 $
- * $Revision: 1.27 $
+ * $Date: 2004/06/20 15:56:47 $
+ * $Revision: 1.2 $
  *
  */
 
 #ifndef UTF8
 #define UTF8
-#endif 
+#endif
 
 #ifndef SLMON_DEFINES_H
 #define SLMON_DEFINES_H
@@ -39,6 +39,7 @@
 #include <sys/utsname.h>
 #include <sys/file.h>
 
+#include <glib.h>
 #include <glibtop/cpu.h>
 #include <glibtop/uptime.h>
 #include <glibtop/mem.h>
@@ -47,7 +48,6 @@
 #include <glibtop/procmap.h>
 #include <glibtop/mountlist.h>
 #include <glibtop/fsusage.h>
-#include <glibtop/xmalloc.h>
 
 #ifndef PROFILE_COUNT
 #define PROFILE_COUNT   1000
@@ -83,8 +83,8 @@ struct last {
 
 struct last l[GLIBTOP_NCPU];	/* we have to remember data for all cpus */
 
-static int unit_div[3] = { 1, 1024, 1048576 };	/* unit dividers */
-static char unit_name[4] = { 'b', 'k', 'M', 'G' };	/* unit letters  */
+static const int unit_div[3] = { 1, 1024, 1048576 };	/* unit dividers */
+static const char unit_name[4] = { 'b', 'k', 'M', 'G' };	/* unit letters  */
 unsigned long update_time;
 
 /* main configuration is kept here */
@@ -160,7 +160,7 @@ static char *slangColors[] = { "black", "red", "green", "brown",
 };
 */
 
-static struct option slmon_options[] = {
+static const struct option slmon_options[] = {
     {"version", no_argument, 0, 'v'},
     {"help", no_argument, 0, 'h'},
     {"mem-unit", required_argument, 0, 'm'},
@@ -168,12 +168,12 @@ static struct option slmon_options[] = {
     {"net-unit", required_argument, 0, 'n'},
     {"mode", required_argument, 0, 'd'},
     {"update", required_argument, 0, 'u'},
-    {0, 0, 0, 0}
+    {NULL, 0, 0, 0}
 };
 
 /* TODO: add colors */
 
-static struct slmon_conf rc_conf[] = {
+static const struct slmon_conf rc_conf[] = {
     {"mode", 0, 'd'},
     {"mem_unit", 0, 'm'},
     {"fs_unit", 0, 'f'},
