@@ -15,9 +15,10 @@
  * COPYING text.
  *
  * Author: Krzysztof Luks <m00se@iq.pl>
+ * Some changes contributed by Ryan Wood
  *
- * $Date: 2002/07/05 17:51:15 $
- * $Revision: 1.31 $
+ * $Date: 2004/06/20 15:56:48 $
+ * $Revision: 1.8 $
  *
  */
 
@@ -305,7 +306,7 @@ void print_keys(int mode)
 	SLsmg_write_string("h: histogram mode");
 	break;
     case MODE_N:
-	SLsmg_write_string("u: net unit");
+	SLsmg_write_string("u: net unit n: new interface d: delete interface");
 	break;
     case MODE_P:
 	SLsmg_write_string("PgUp,PgDown,up,down: scroll, k:SIGTERM, K:spec signal");
@@ -313,7 +314,6 @@ void print_keys(int mode)
     case MODE_X:
 	SLsmg_write_string("SPC,ENTER:  leave help");
 	break;
-    default:
     }
 }
 
@@ -397,8 +397,8 @@ void print_fs(int r, int c)
 			 fs_size, fs_used, fs_avail, unit);
 	j++;
     }
-    glibtop_free(me);
-    glibtop_free(me_valid);
+    g_free(me);
+    g_free(me_valid);
     conf.gauge_len = gauge_tmp;
 
     /* if we haven't displayed all entries we need to draw a scrollbar */
@@ -410,18 +410,14 @@ void print_fs(int r, int c)
     }
 }
 
-int print_iface(int r, int c, char *name, long last_in, long last_out)
+int print_iface(int r, int c, char *name, unsigned long last_in, unsigned long last_out)
 {
     glibtop_netload nload;
     unsigned long mtu, s, a, p_in, p_out, e_in, e_out, coll;
-#ifdef HAVE_INET_NTOP
-    char add[20] = { 0 }, sub[20] = { 0 };
-#else
-    char *add, *sub;
-    struct in_addr in;
-#endif
-    double b_in, b_out, speed, scale;
-    char flags[80] = { 0 }, un;
+    char add[20] = { 0 }, sub[20] = { 0 }, un;
+    double b_in, b_out, speed_in, speed_out, scale;
+    char un_in, un_out;
+    char flags[80] = { 0 };
 
     glibtop_get_netload(&nload, name);
 
@@ -450,48 +446,75 @@ int print_iface(int r, int c, char *name, long last_in, long last_out)
     e_in = (unsigned long) nload.errors_in;
     e_out = (unsigned long) nload.errors_out;
     coll = (unsigned long) nload.collisions;
-    speed = (double) (nload.bytes_in - last_in) + (nload.bytes_out - last_out);
+    speed_in = (double) (nload.bytes_in - last_in);
+    speed_out = (double) (nload.bytes_out - last_out);
     scale = (double) 1000000 / (update_time + 10000);
-    speed *= scale;
-    
-    speed /= unit_div[conf.net];
-    
+    speed_in *= scale;
+    speed_out *= scale;
+
+    if ( speed_in >= 524288 ) {
+	speed_in /= 1048576;
+	un_in = 'M';
+    } else {
+	speed_in /= 1024;
+	un_in = 'k';
+    }
+    if ( speed_out >= 524288 ) {
+	speed_out /= 1048576;
+	un_out = 'M';
+    } else {
+	speed_out /= 1024;
+	un_out = 'k';
+    }
+
     slmon_update_net_throughput(name, nload.bytes_in, nload.bytes_out);
 
     un = unit_name[conf.net];
 
-#ifdef HAVE_INET_NTOP
     inet_ntop(AF_INET, &s, sub, 19);
     inet_ntop(AF_INET, &a, add, 19);
-#else
-    in.s_addr = s;
-    sub = inet_ntoa(in);
-    in.s_addr = a;
-    add = inet_ntoa(in);
-#endif
-    
+
     SLsmg_gotorc(r, c);
-    SLsmg_set_color(6);
-    SLsmg_printf("%s", name);
     SLsmg_set_color(7);
-    SLsmg_gotorc(r, c + strlen(name) + 5);
-    SLsmg_write_string(flags);
-    SLsmg_gotorc(r + 1, c);
-    SLsmg_printf("Address: %s Subnet: %s, MTU: %d", add, sub, mtu);
-    SLsmg_gotorc(r + 2, c);
-    SLsmg_printf("Packets in: %d, Packets out: %d, ", p_in, p_out);
-    if (conf.net == 0)
-	SLsmg_printf("Bytes in: %.lf%c, Bytes out: %.lf%c", b_in, un,
-		     b_out, un);
-    else
-	SLsmg_printf("Bytes in: %.1lf%c, Bytes out: %.1lf%c", b_in, un,
-		     b_out, un);
 
-    SLsmg_gotorc(r + 3, c);
-    SLsmg_printf("Errors in: %d, Errors out: %d, Collisions: %d, Speed: %.2lf%c/s", e_in,
-		 e_out, coll, speed, un);
-
-    return 5;
+    SLsmg_printf("%s", name);
+    SLsmg_gotorc(r, c  + 8);
+    SLsmg_printf("%s", add);
+    SLsmg_gotorc(r, c  + 26);
+    SLsmg_printf("%d", coll);
+    SLsmg_gotorc(r, c  + 37);
+    
+    if (conf.net == 0){
+	SLsmg_printf("%.lf%c", b_out, un);
+	SLsmg_gotorc(r, c  + 47);
+	if (un_out == 'M')
+	    SLsmg_set_color(15);
+	SLsmg_printf("%.2lf%c/s", speed_out, un_out);
+	SLsmg_set_color(7);
+	SLsmg_gotorc(r, c  + 58);
+	SLsmg_printf("%.lf%c", b_in, un);
+	SLsmg_gotorc(r, c  + 68);
+	if (un_in == 'M')
+	    SLsmg_set_color(15);
+	SLsmg_printf("%.2lf%c/s", speed_in, un_in);
+	SLsmg_set_color(7);
+     } else {
+	SLsmg_printf("%.1lf%c", b_out, un);
+	SLsmg_gotorc(r, c  + 47);
+	if (un_out == 'M')
+	    SLsmg_set_color(15);
+	SLsmg_printf("%.2lf%c/s", speed_out, un_out);
+	SLsmg_set_color(7);
+	SLsmg_gotorc(r, c  + 58);
+	SLsmg_printf("%.1lf%c", b_in, un);
+	SLsmg_gotorc(r, c  + 68);
+	if (un_in == 'M')
+	    SLsmg_set_color(15);
+	SLsmg_printf("%.2lf%c/s", speed_in, un_in);
+	SLsmg_set_color(7);
+     }
+    
+    return 1; //height of status
 }
 
 /*
@@ -553,11 +576,10 @@ void draw_mode_g(void)
 
 void draw_mode_n(void)
 {
-    char tmp[20] = { 0 };
     struct slmon_net *net;
-    int i, j = 0, num = 0, first, draw = 0;
+    int num = 0, first;
 
-    if (conf.iface == NULL) {
+    if (conf.iface == NULL || conf.iface_count == 0) {
 	SLsmg_gotorc(5, (SLtt_Screen_Cols / 2) - 12);
 	SLsmg_set_color(7);
 	SLsmg_write_string("No interfaces specified.");
@@ -579,13 +601,17 @@ void draw_mode_n(void)
 
     /* print the remaining ones */
     while(net != NULL) {
-	if(num + 4 > SLtt_Screen_Rows - 4)
+	if(num + 3 > SLtt_Screen_Rows - 2)
 	    break; /* no more space left on screen */
 	num += print_iface(2 + num, 1, net->name, net->last_in, net->last_out);
 	net = net->next;
     }
 
     /* draw scrollbar */
+    SLsmg_gotorc(1, 1);
+    SLsmg_set_color(6);
+    SLsmg_printf("INT     IP                Collisions Sent:     k/s        Recieved: k/s");
+    SLsmg_set_color(7);
     draw_scrollbar(2, 0, SLtt_Screen_Rows - 4, (conf.iface_first * 100) / conf.iface_count);
 }
 
@@ -716,3 +742,6 @@ void slmon_status_msg(char *format, ...)
     va_end(ptr);
     SLsmg_refresh();
 }
+
+
+
