@@ -9,8 +9,8 @@
  *
  * Author: Krzysztof Luks <m00se@iq.pl>
  *
- * $Date: 2002/04/01 16:16:07 $
- * $Revision: 1.3 $
+ * $Date: 2004/06/20 15:56:48 $
+ * $Revision: 1.2 $
  *
  */
 
@@ -19,7 +19,7 @@
 
 #include "defines.h"
 
-int slmon_getconf(struct slmon_conf conf[], char *key);
+int slmon_getconf(const struct slmon_conf conf[], const char *key);
 char *slmon_strip(char *string);
 char *slmon_split(char *str, char sep, int *pos);
 int slmon_conf_parse(FILE * f);
