@@ -9,8 +9,8 @@
  *
  * Author: Krzysztof Luks <m00se@iq.pl>
  *
- * $Date: 2002/04/01 16:29:56 $
- * $Revision: 1.30 $
+ * $Date: 2004/06/20 15:56:48 $
+ * $Revision: 1.2 $
  *
  */
 
@@ -64,17 +64,13 @@ void slmon_getopt_help(void);
 
 int main(int argc, char **argv)
 {
-    int j, arg;
-    extern int cpus, cur_cpu;
-    SLKeyMap_List_Type *kmap;
+    extern int cur_cpu;
     SLang_Key_Type *key;
 #ifdef HAVE_GETOPT_LONG
     int c;
 #endif				/* !HAVE_GETOPT_LONG */
     glibtop_cpu gcpu;
 
-    char capt[20] = { 0 };
-
     /* Variables initialization */
     cur_cpu = 0;
     conf.mem = 2;
@@ -336,7 +332,6 @@ void slmon_update_current_keymap(void)
     case MODE_X:
 	conf.map = conf.map_x;
 	break;
-    default:
     }
 }
 
@@ -513,7 +508,6 @@ void slmon_sort_method(void)
     case 'F':
 	conf.sort_func = slmon_cmp_user_asc;
 	break;
-    default:
     }
 }
 
