@@ -9,8 +9,8 @@
  *
  * Author: Krzysztof Luks <m00se@iq.pl>
  *
- * $Date: 2002/07/03 19:13:58 $
- * $Revision: 1.14 $
+ * $Date: 2004/06/24 19:38:35 $
+ * $Revision: 1.3 $
  *
  */
 
@@ -103,18 +103,12 @@ int users(void)
 
 char *cpu_caption(int num)
 {
-    char *t;
-    char c[3];
+    char *t = calloc(20, 1);
 
-    t = calloc(20, sizeof(char));
     if (num == 0) {
 	strcpy(t, "Total CPU usage");
-	return t;
     } else {
-	strcpy(t, "CPU");
-	sprintf(c, "%c", '0' + num);
-	strcat(t, c);
-	strcat(t, " usage");
+        sprintf(t, "CPU%d usage", num);
     }
     return t;
 }
@@ -166,12 +160,11 @@ slmon_proc *slmon_get_proclist(int *len)
 		for (j = 0; j < pargs.size; j++)
 		    if (result[i].args[j] == '\0')
 			result[i].args[j] = ' ';
-		glibtop_free(args1);
+		g_free(args1);
 	    } else {
 		tmp = strlen(pstate.cmd) * sizeof(char);
 		result[i].args = (char *) malloc(tmp+1);
-		bzero(result[i].args, tmp+1);
-		memcpy(result[i].args, pstate.cmd, tmp);
+                result[i].args = calloc(tmp + 1, 1);
 	    }
 
 	    result[i].vsz = (int) pmem.vsize >> 10;
@@ -180,10 +173,9 @@ slmon_proc *slmon_get_proclist(int *len)
 	    pwd = getpwuid(pstate.uid);
 	    tmp = strlen(pwd->pw_name) * sizeof(char);
 	    result[i].user = (char *) malloc(tmp + 1);
-	    bzero(result[i].user, tmp + 1);
-	    memcpy(result[i].user, pwd->pw_name, tmp);
+            result[i].user = calloc(tmp + 1, 1);
 	}
-	glibtop_free(pids);
+	g_free(pids);
     }
     memcpy(len, &num, sizeof(int));
     return result;
@@ -256,7 +248,7 @@ int slmon_cmp_user_desc(const void *one, const void *two)
 void slmon_update_net_throughput(char *name, long in, long out)
 {
 	struct slmon_net *tmp;
-	int len = strlen(name);
+        const size_t len = strlen(name);
 	
 	tmp = conf.iface;
 	
@@ -268,7 +260,6 @@ void slmon_update_net_throughput(char *name, long in, long out)
 		}
 		tmp = tmp->next;
 	}
-	
 }
 
 struct slmon_net *slmon_net_new(void)
@@ -278,7 +269,7 @@ struct slmon_net *slmon_net_new(void)
     tmp = (struct slmon_net *) malloc(sizeof(struct slmon_net));
     tmp->name = NULL;
     tmp->next = tmp->prev = NULL;
-
+    
     return tmp;
 }
 
@@ -289,9 +280,8 @@ struct slmon_net *slmon_net_append(struct slmon_net *l, char *name)
 
     tmp = slmon_net_new();
     len = strlen(name);
-    tmp->name = (char *) malloc(len * sizeof(char) + 1);
-    bzero(tmp->name, len + 1);
-    strncpy(tmp->name, name, len);
+    tmp->name = calloc(len + 1, 1);
+    memcpy(tmp->name, name, len);
     tmp->last_in = tmp->last_out = 0;
 
     if(l != NULL) {
@@ -373,3 +363,4 @@ struct slmon_net *slmon_net_find(struct slmon_net *l, char *name)
 
     return j;
 }
+
